@@ -126,7 +126,7 @@ def run(email, file, path):
         aggregate_output.extend(backtrace.stdout)
         aggregate_output.extend(b'\n' + b'=' * 80 + b'\n\n\n')
 
-    if email and len(success):
+    if email and success:
         msg = EmailMessage()
         msg.set_content(aggregate_output.decode('UTF-8'))
         msg['Subject'] = f'[CRASHALYSER] Automated email: backtraces from core dumps on {platform.node()}'
@@ -142,11 +142,16 @@ def run(email, file, path):
         server.quit()
         click.echo(f"Sent email report to {email}")
 
-    if file and len(success):
+    if file and success:
         with open(file, 'w') as f:
             f.write(aggregate_output.decode('utf-8'))
         click.echo(f"Wrote {len(success)} backtraces to {file}")
 
+    if success:
+        for f in success:
+            if os.path.exists(f):
+                os.remove(f)
+
 
 def read_config():
     cfg_system = os.path.join('/etc/crashalyser', 'config.ini')
